# -*- coding: utf-8 -*-
# Generated by Django 1.9.4 on 2016-04-05 06:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_blog_it', '0005_auto_20160330_0539'),
    ]

    operations = [
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100)),
                ('content', models.TextField()),
                ('slug', models.SlugField()),
                ('is_active', models.BooleanField(default=True)),
                ('meta_description', models.TextField()),
                ('keywords', models.TextField()),
                ('meta_title', models.TextField()),
            ],
        ),
    ]
