<!DOCTYPE html>
<html lang="en"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>{{ BLOG_TITLE }}</title>
    <link href="./Micro Track leaves view to admin_files/css" rel="stylesheet" type="text/css">
  </head>
  <body style="width:100% !important; margin:0 !important; padding:0 !important; -webkit-text-size-adjust:none; -ms-text-size-adjust:none;font-size:13px; font-family: &#39;Karla&#39;, sans-serif;color: #73879C; background: #e8edf2; ">
   <table cellpadding="0" cellspacing="0" border="0" id="backgroundTable" style="height:auto !important; margin:0; padding:0; width:100% !important; font-family: &#39;Karla&#39;, sans-serif;color: #73879C; background: #e8edf2;">
      <tbody><tr>
         <td>
          <table id="contenttable" width="800" align="center" cellpadding="0" cellspacing="0" border="0" style="font-family: &#39;Karla&#39;, sans-serif;color: #73879C; background: #fff; text-align:center !important; margin-top:0 !important; margin-right: auto !important; margin-bottom:0 !important; margin-left: auto !important; border:none; width: 100% !important; max-width:800px !important;border: 1px solid #ddd !important;">
              <tbody><tr>
                <td>
                  <table style="width:800px;background:#fff;padding:0;" cellpadding="0" cellspacing="0">
                    <tbody><tr>
                      <td style="background: #2A3F54;height:50px;">
                        <a href="#" style="text-overflow: ellipsis;overflow: hidden;width: 100%;color: #c4d0d9 !important;margin-left: 0 !important;display: block;margin: 0; padding:0;font-weight: bold;text-transform: uppercase;font-size: 18px;text-decoration:none;"><i class="fa fa-line-chart" aria-hidden="true"></i> {{ BLOG_TITLE }}</a>
                      </td>
                    </tr>
                    <tr style="background:#fff;">
                      <td>
                        <table style="width:100%; text-align:left;">
                          <tr>
                            <td width="6%" style="font-size: 17px;">Name</td> <td>: {{ NAME_OF_USER }}</td>
                          </tr>
                          <tr>
                            <td style="font-size: 17px;">website </td> <td>: {{ WEBSITE_OF_USER }}</td>
                          </tr>
                          <tr>
                            <td colspan="2" style="font-size: 17px;">Description</td>
                          </tr>
                          <tr>
                            <td colspan="2">
                              {{ USER_DESCRIPTION }}
                            </td>
                          </tr>
                        </table>
                      </td>
                    </tr>
                    <tr>
                     <td style="font-weight: bold;padding:12px 0;color: #333 !important;text-decoration: none;background: #e8edf2;">
                      Yours sincerely, Administration of the service, {{ BLOG_TITLE }}.
                    </td>
                    </tr>
                  </tbody></table>
                </td>
              </tr>
            </tbody></table>    
         </td>
      </tr>
    </tbody></table>     

  
</body></html>