# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-07-28 11:37
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_blog_it', '0013_facebook'),
    ]

    operations = [
        migrations.CreateModel(
            name='Post_Slugs',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(max_length=100, unique=True)),
                ('is_active', models.BooleanField(default=False)),
                ('blog', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='slugs', to='django_blog_it.Post')),
            ],
        ),
    ]
