# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-05-31 11:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_blog_it', '0007_menu'),
    ]

    operations = [
        migrations.AddField(
            model_name='post',
            name='featured_image',
            field=models.ImageField(blank=True, null=True, upload_to=b'static/blog/uploads/%Y/%m/%d/'),
        ),
    ]
